import React, { useState } from 'react';
import { Box, Typography } from '@mui/material';
import styled from 'styled-components';
import Slot, { SlotData } from './Slots';

const StorageContainer = styled(Box)`
    display: flex;
    flex-direction: column;
    align-items: center;
    margin-top: 20px;
    width: 100%;
`;

const StorageWrapper = styled.div`
    display: flex;
    flex-wrap: wrap;
    justify-content: center;
    width: 90%;
    background-color: #dcdcdc;
    padding: 20px;
    border-radius: 10px;
    box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
    margin-bottom: 20px;
`;

interface StorageProps {
    name: string;
    selectedSlot: string | null;
}


const storageSlotsData: { [key: string]: SlotData[] } = {
    "X06SA-storage": [
        { id: "A1-X06SA", occupied: false, needsRefill: false, timeUntilRefill: '' },
        { id: "A2-X06SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "A3-X06SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "A4-X06SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "A5-X06SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "B1-X06SA", occupied: false, needsRefill: false, timeUntilRefill: '' },
        { id: "B2-X06SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "B3-X06SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "B4-X06SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "B5-X06SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "C1-X06SA", occupied: false, needsRefill: false, timeUntilRefill: '' },
        { id: "C2-X06SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "C3-X06SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "C4-X06SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "C5-X06SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "D1-X06SA", occupied: false, needsRefill: false, timeUntilRefill: '' },
        { id: "D2-X06SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "D3-X06SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "D4-X06SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "D5-X06SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
    ],
    "X10SA-storage": [
        { id: "A1-X10SA", occupied: false, needsRefill: false, timeUntilRefill: '' },
        { id: "A2-X10SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "A3-X10SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "A4-X10SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "A5-X10SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "B1-X10SA", occupied: false, needsRefill: false, timeUntilRefill: '' },
        { id: "B2-X10SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "B3-X10SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "B4-X10SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "B5-X10SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "C1-X10SA", occupied: false, needsRefill: false, timeUntilRefill: '' },
        { id: "C2-X10SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "C3-X10SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "C4-X10SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "C5-X10SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "D1-X10SA", occupied: false, needsRefill: false, timeUntilRefill: '' },
        { id: "D2-X10SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "D3-X10SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "D4-X10SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
        { id: "D5-X10SA", occupied: true, needsRefill: true, timeUntilRefill: '12h' },
    ],
    "Novartis-Box": [
        { id: "NB1", occupied: true, needsRefill: true, timeUntilRefill: '6h' },
        { id: "NB2", occupied: true, needsRefill: true, timeUntilRefill: '6h' },
        { id: "NB3", occupied: true, needsRefill: true, timeUntilRefill: '6h' },
        { id: "NB4", occupied: true, needsRefill: true, timeUntilRefill: '6h' },
        { id: "NB5", occupied: true, needsRefill: true, timeUntilRefill: '6h' },
        { id: "NB6", occupied: true, needsRefill: true, timeUntilRefill: '6h' },
    ],
};

const Storage: React.FC<StorageProps> = ({ name, selectedSlot }) => {
    const [highlightedSlot, setHighlightedSlot] = useState<SlotData | null>(null);

    const handleSlotSelect = (slot: SlotData) => {
        setHighlightedSlot(slot);
    };

    return (
        <StorageContainer>
            <Typography variant="h5">{name} Slots</Typography>
            <StorageWrapper>
                {storageSlotsData[name].map((slot) => (
                    <Slot
                        key={slot.id}
                        data={slot}
                        onSelect={handleSlotSelect}
                        isSelected={selectedSlot === slot.id}
                    />
                ))}
            </StorageWrapper>
            {highlightedSlot && (
                <Typography variant="subtitle1">
                    Selected Slot: {highlightedSlot.id}
                </Typography>
            )}
        </StorageContainer>
    );
}

export default Storage;